@@ -5,7 +5,7 @@
 **
 ** Comments: Dump IP header information
 **
-** $Id: ip.c,v 1.22 2001/09/07 20:59:11 mborella Exp $
+** $Id: ip.c,v 1.24 2001/11/15 00:22:36 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -121,11 +121,12 @@ void dump_ip(packet_t *pkt)
   if (my_args->m)
     {
       u_int16_t new_fo = frag_off * 8;
- 
+
       display_minimal_string("| IP ");
       display_minimal_ipv4((u_int8_t *) &ip.src); 
       display_minimal_string("->");
       display_minimal_ipv4((u_int8_t *) &ip.dst); 
+
       display_minimal_string(" (len:");
       display_minimal((u_int8_t *) &ip.length, 2, DISP_DEC);
       display_minimal_string(",id:");
@@ -174,10 +175,11 @@ void dump_ip(packet_t *pkt)
       display_ipv4("Destination address", (u_int8_t *) &ip.dst); 
     }
 
-  /*
-   * Check for IP options
-   */
-
+  /* set IP address state */
+  state_set_srcaddr(ntohl(ip.src));
+  state_set_dstaddr(ntohl(ip.dst));
+  
+  /* check for IP options */
   if (hlen > 5)
     dump_ip_options(pkt, hlen * 4 - 20);
 
