@@ -5,7 +5,7 @@
 **
 ** Comments: Dump OSPF information
 **
-** $Id: ospf.c,v 1.12 2001/09/07 20:59:11 mborella Exp $
+** $Id: ospf.c,v 1.13 2001/10/11 20:43:50 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -212,5 +212,7 @@ void dump_ospf(packet_t *pkt)
       break;
     }
 
+  /* Dump the hex buffer */
+  hexbuffer_flush();
 }
 
