@@ -6,7 +6,7 @@
 **
 ** Comments: Dump TCP header information. 
 **
-** $Id: tcp.c,v 1.21 2001/09/07 20:59:11 mborella Exp $
+** $Id: tcp.c,v 1.23 2001/10/12 21:45:02 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -215,7 +215,8 @@ void dump_tcp(packet_t *pkt)
   tcp_header_t tcp;
   u_int8_t hlen, unused;
   char flag_str[8];
-  service_func_t app;
+  service_func_t app_src;
+  service_func_t app_dst;
   char holder[64];
 
 #ifdef DEBUG
@@ -320,6 +321,9 @@ void dump_tcp(packet_t *pkt)
       display("Urgent", (u_int8_t *) &tcp.urgent, 2, DISP_DEC);
     }
   
+  /* Add state */
+  state_set_srcport(tcp.src);
+  state_set_dstport(tcp.dst);
   
   /*
    * Handle any options. There should be option(s) if the header length
@@ -339,27 +343,28 @@ void dump_tcp(packet_t *pkt)
 
   if (get_packet_apparentbytesleft(pkt))
     {
-      /*
-       * Let's see if we can decode the application from the source port...
+      /* 
+       * Let's try to decode the application from the port number.  If both 
+       * match a decoder, we choose the lowest, assuming that the higher 
+       * one is probably ephemeral.
        */
-      
-      app = port2func(tcp.src);
-      if (app)
+
+      app_src = port2func(tcp.src);
+      app_dst = port2func(tcp.dst);
+      if (app_src && app_dst)
 	{
-	  app(pkt);
-	  return;
+	  if (tcp.src < tcp.dst)
+	    app_src(pkt);
+	  else
+	    app_dst(pkt);
 	}
-      
-      /*
-       * Let's see if we can decode the application from the destination 
-       * port...
-       */
-      
-      app = port2func(tcp.dst);
-      if (app)
+      else
 	{
-	  app(pkt);
-	  return;
+	  if (app_src)
+	app_src(pkt);
+	  else
+	    if (app_dst)
+	      app_dst(pkt);
 	}
     }
 
