@@ -6,7 +6,7 @@
 ** Comments: General utility functions that are not tied to IPgrab in any
 ** particular way.
 **
-** $Id: utilities.c,v 1.5 2001/09/07 22:50:31 mborella Exp $
+** $Id: utilities.c,v 1.6 2001/11/15 00:22:36 mborella Exp $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,9 +26,16 @@
 
 #define BUF_SIZE      128
 
+#include <sys/socket.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 #include "utilities.h"
 #include "error.h"
 
+#define SPACESTR_SIZE 128
+
+char space_str[SPACESTR_SIZE];
+
 /*----------------------------------------------------------------------------
 **
 ** reverse_byte_order()
@@ -217,3 +224,56 @@ inline void dump_hex_and_text(char * buffer, int len)
     }
   while(buf_ptr < buf_end);
 }
+
+/*----------------------------------------------------------------------------
+**
+** ipaddr_space()
+**
+** Takes an IP address in network byte order, and figures out how many
+** spaces are needed to pretty print it so that it lines up with other
+** addresses in minimal mode.
+**
+** Returns -1 on error.
+**----------------------------------------------------------------------------
+*/
+
+inline int ipaddr_space(u_int32_t ipaddr)
+{
+  char * ptr;
+  struct in_addr * ip_holder;
+
+  ip_holder = (struct in_addr *) &ipaddr;
+  ptr = inet_ntoa(*ip_holder);
+
+  if (ptr)
+    return 15-strlen(ptr);
+  else
+    return -1;
+}
+
+/*----------------------------------------------------------------------------
+**
+** make_space_str()
+**
+** Given a number of bytes, returns a string of that size.  Note that this 
+** string is a global, defined above.
+**
+** Returns NULL if the number of sapces requested is not sane (smaller than 0
+** or bigger than SPACESTR_SIZE).
+**
+**----------------------------------------------------------------------------
+*/
+
+inline char * make_space_str(int n)
+{
+  int i;
+  
+  if (n < 0 || n > SPACESTR_SIZE-1)
+    return NULL;
+
+  for (i=0; i<n; i++)
+    space_str[i] = ' ';
+  space_str[n] = '\0';
+
+  return space_str;
+}
